@@ -48,6 +48,7 @@ import freemarker.template.TemplateScalarModel;
 import freemarker.template.TemplateSequenceModel;
 import freemarker.template.TemplateTransformModel;
 import freemarker.template._TemplateAPI;
+import freemarker.template._VersionInts;
 import freemarker.template.utility.NumberUtil;
 
 /**
@@ -55,86 +56,52 @@ import freemarker.template.utility.NumberUtil;
  */
 class BuiltInsForMultipleTypes {
 
-    static class cBI extends AbstractCBI implements ICIChainMember {
-        
-        static class BIBeforeICI2d3d21 extends AbstractCBI {
-
-            @Override
-            protected TemplateModel formatNumber(Environment env, TemplateModel model) throws TemplateModelException {
-                Number num = EvalUtil.modelToNumber((TemplateNumberModel) model, target);
-                if (num instanceof Integer || num instanceof Long) {
-                    // Accelerate these fairly common cases
-                    return new SimpleScalar(num.toString());
-                } else {
-                    return new SimpleScalar(env.getCNumberFormat().format(num));
-                }
-            }
-            
+    static class cBI extends AbstractCLikeBI {
+        final protected String formatNull(Environment env) throws InvalidReferenceException {
+            throw InvalidReferenceException.getInstance(target, env);
         }
-        
-        private final BIBeforeICI2d3d21 prevICIObj = new BIBeforeICI2d3d21();
+    }
+
+    static class cnBI extends AbstractCLikeBI {
+        final protected String formatNull(Environment env) {
+            return env.getCFormat().getNullString();
+        }
+    }
+
+    private static abstract class AbstractCLikeBI extends BuiltIn {
 
         @Override
-        TemplateModel _eval(Environment env) throws TemplateException {
-            TemplateModel model = target.eval(env);
+        final TemplateModel _eval(Environment env) throws TemplateException {
+            final String result;
+            final TemplateModel model = target.eval(env);
             if (model instanceof TemplateNumberModel) {
-                return formatNumber(env, model);
+                TemplateNumberFormat cTemplateNumberFormat = env.getCTemplateNumberFormat();
+                try {
+                    result = cTemplateNumberFormat.formatToPlainText((TemplateNumberModel) model);
+                } catch (TemplateValueFormatException e) {
+                    throw _MessageUtil.newCantFormatNumberException(cTemplateNumberFormat, target, e, false);
+                }
             } else if (model instanceof TemplateBooleanModel) {
-                return new SimpleScalar(((TemplateBooleanModel) model).getAsBoolean()
-                        ? MiscUtil.C_TRUE : MiscUtil.C_FALSE);
+                boolean b = ((TemplateBooleanModel) model).getAsBoolean();
+                CFormat cFormat = env.getCFormat();
+                result = b ? cFormat.getTrueString() : cFormat.getFalseString();
+            } else if (model instanceof TemplateScalarModel) {
+                String s = EvalUtil.modelToString((TemplateScalarModel) model, target, env);
+                result = env.getCFormat().formatString(s, env);
+            } else if (model == null) {
+                result = formatNull(env);
             } else {
                 throw new UnexpectedTypeException(
                         target, model,
-                        "number or boolean", new Class[] { TemplateNumberModel.class, TemplateBooleanModel.class },
+                        "number, boolean, or string",
+                        new Class[] { TemplateNumberModel.class, TemplateBooleanModel.class, TemplateScalarModel.class },
                         env);
             }
+            return new SimpleScalar(result);
         }
 
-        @Override
-        protected TemplateModel formatNumber(Environment env, TemplateModel model) throws TemplateModelException {
-            Number num = EvalUtil.modelToNumber((TemplateNumberModel) model, target);
-            if (num instanceof Integer || num instanceof Long) {
-                // Accelerate these fairly common cases
-                return new SimpleScalar(num.toString());
-            } else if (num instanceof Double) {
-                double n = num.doubleValue();
-                if (n == Double.POSITIVE_INFINITY) {
-                    return new SimpleScalar("INF");
-                }
-                if (n == Double.NEGATIVE_INFINITY) {
-                    return new SimpleScalar("-INF");
-                }
-                if (Double.isNaN(n)) {
-                    return new SimpleScalar("NaN");
-                }
-                // Deliberately falls through
-            } else if (num instanceof Float) {
-                float n = num.floatValue();
-                if (n == Float.POSITIVE_INFINITY) {
-                    return new SimpleScalar("INF");
-                }
-                if (n == Float.NEGATIVE_INFINITY) {
-                    return new SimpleScalar("-INF");
-                }
-                if (Float.isNaN(n)) {
-                    return new SimpleScalar("NaN");
-                }
-                // Deliberately falls through
-            }
-        
-            return new SimpleScalar(env.getCNumberFormat().format(num));
-        }
+        protected abstract String formatNull(Environment env) throws InvalidReferenceException;
 
-        @Override
-        public int getMinimumICIVersion() {
-            return _TemplateAPI.VERSION_INT_2_3_21;
-        }
-        
-        @Override
-        public Object getPreviousICIChainMember() {
-            return prevICIObj;
-        }
-        
     }
 
     static class dateBI extends BuiltIn {
@@ -355,7 +322,7 @@ class BuiltInsForMultipleTypes {
             TemplateModel tm = target.eval(env);
             target.assertNonNull(tm, env);
             return (tm instanceof TemplateSequenceModel || tm instanceof TemplateCollectionModel)
-                    && (_TemplateAPI.getTemplateLanguageVersionAsInt(this) < _TemplateAPI.VERSION_INT_2_3_21
+                    && (_TemplateAPI.getTemplateLanguageVersionAsInt(this) < _VersionInts.V_2_3_21
                         // These implement TemplateSequenceModel, yet they can't be #list-ed:
                         || !(tm instanceof SimpleMethodModel || tm instanceof OverloadedMethodsModel))
                     ? TemplateBooleanModel.TRUE : TemplateBooleanModel.FALSE;
@@ -792,26 +759,4 @@ class BuiltInsForMultipleTypes {
     // Can't be instantiated
     private BuiltInsForMultipleTypes() { }
 
-    static abstract class AbstractCBI extends BuiltIn {
-        
-        @Override
-        TemplateModel _eval(Environment env) throws TemplateException {
-            TemplateModel model = target.eval(env);
-            if (model instanceof TemplateNumberModel) {
-                return formatNumber(env, model);
-            } else if (model instanceof TemplateBooleanModel) {
-                return new SimpleScalar(((TemplateBooleanModel) model).getAsBoolean()
-                        ? MiscUtil.C_TRUE : MiscUtil.C_FALSE);
-            } else {
-                throw new UnexpectedTypeException(
-                        target, model,
-                        "number or boolean", new Class[] { TemplateNumberModel.class, TemplateBooleanModel.class },
-                        env);
-            }
-        }
-    
-        protected abstract TemplateModel formatNumber(Environment env, TemplateModel model) throws TemplateModelException;
-        
-    }
-
 }
