@@ -45,7 +45,7 @@ import freemarker.template.TemplateModelListSequence;
 import freemarker.template.TemplateNumberModel;
 import freemarker.template.TemplateScalarModel;
 import freemarker.template.TemplateSequenceModel;
-import freemarker.template._TemplateAPI;
+import freemarker.template._ObjectWrappers;
 import freemarker.template.utility.Constants;
 import freemarker.template.utility.StringUtil;
 
@@ -889,8 +889,8 @@ class BuiltInsForSequences {
                         coll instanceof TemplateCollectionModelEx
                                 ? new SimpleSequence(
                                         ((TemplateCollectionModelEx) coll).size(),
-                                        _TemplateAPI.SAFE_OBJECT_WRAPPER)
-                                : new SimpleSequence(_TemplateAPI.SAFE_OBJECT_WRAPPER);
+                                        _ObjectWrappers.SAFE_OBJECT_WRAPPER)
+                                : new SimpleSequence(_ObjectWrappers.SAFE_OBJECT_WRAPPER);
                 for (TemplateModelIterator iter = coll.iterator(); iter.hasNext(); ) {
                     seq.add(iter.next());
                 }
