@@ -34,7 +34,9 @@ import freemarker.template.TemplateModelIterator;
 import freemarker.template.TemplateNumberModel;
 import freemarker.template.TemplateScalarModel;
 import freemarker.template.TemplateSequenceModel;
+import freemarker.template._ObjectWrappers;
 import freemarker.template._TemplateAPI;
+import freemarker.template._VersionInts;
 import freemarker.template.utility.Constants;
 
 /**
@@ -291,7 +293,7 @@ final class DynamicKeyName extends Expression {
                 srcIdx += step;
             }
             // List items are already wrapped:
-            return new SimpleSequence(resultList, _TemplateAPI.SAFE_OBJECT_WRAPPER);
+            return new SimpleSequence(resultList, _ObjectWrappers.SAFE_OBJECT_WRAPPER);
         } else if (targetLazySeq != null) {
             // As a targetLazySeq can only occur if a new built-in like ?filter or ?map was used somewhere in the target
             // expression, in this case we can return lazily generated sequence without breaking backward compatibility.
@@ -386,7 +388,7 @@ final class DynamicKeyName extends Expression {
                 resultList.add(targetIter.next());
             }
             // List items are already wrapped:
-            return new SimpleSequence(resultList, _TemplateAPI.SAFE_OBJECT_WRAPPER);
+            return new SimpleSequence(resultList, _ObjectWrappers.SAFE_OBJECT_WRAPPER);
         }
     }
 
@@ -433,13 +435,13 @@ final class DynamicKeyName extends Expression {
                     "Range top index " + highIndex + " (0-based) is outside the sliced sequence of length " +
                     srcIdx + ".");
         }
-        return new SimpleSequence(Arrays.asList(resultElements), _TemplateAPI.SAFE_OBJECT_WRAPPER);
+        return new SimpleSequence(Arrays.asList(resultElements), _ObjectWrappers.SAFE_OBJECT_WRAPPER);
     }
 
     private TemplateModel emptyResult(boolean seq) {
         return seq
-                ? (_TemplateAPI.getTemplateLanguageVersionAsInt(this) < _TemplateAPI.VERSION_INT_2_3_21
-                        ? new SimpleSequence(_TemplateAPI.SAFE_OBJECT_WRAPPER)
+                ? (_TemplateAPI.getTemplateLanguageVersionAsInt(this) < _VersionInts.V_2_3_21
+                        ? new SimpleSequence(_ObjectWrappers.SAFE_OBJECT_WRAPPER)
                         : Constants.EMPTY_SEQUENCE)
                 : TemplateScalarModel.EMPTY_STRING;
     }
