@@ -33,7 +33,7 @@ import freemarker.template.TemplateModelException;
 import freemarker.template.TemplateNumberModel;
 import freemarker.template.TemplateScalarModel;
 import freemarker.template.TemplateSequenceModel;
-import freemarker.template._TemplateAPI;
+import freemarker.template._VersionInts;
 
 /**
  * Internally used static utilities for evaluation expressions.
@@ -481,7 +481,7 @@ class EvalUtil {
                     throw InvalidReferenceException.getInstance(exp, env);
                 } else {
                     throw new InvalidReferenceException(
-                            "Null/missing value (no more informatoin avilable)",
+                            "Null/missing value (no more information available)",
                             env);
                 }
             }
@@ -602,7 +602,7 @@ class EvalUtil {
         }
         if (env.getWrapUncheckedExceptions()) {
             return true;
-        } else if (env.getConfiguration().getIncompatibleImprovements().intValue() >= _TemplateAPI.VERSION_INT_2_3_27) {
+        } else if (env.getConfiguration().getIncompatibleImprovements().intValue() >= _VersionInts.V_2_3_27) {
             // We have to judge if we dare to wrap this exception, or it's too likely that some applications try to
             // catch it around the template processing to do something special. For the same reason, we only wrap very
             // frequent exceptions.
