@@ -29,6 +29,7 @@ import freemarker.template.Configuration;
 import freemarker.template.Template;
 import freemarker.template.Version;
 import freemarker.template._TemplateAPI;
+import freemarker.template._VersionInts;
 import freemarker.template.utility.NullArgumentException;
 
 /**
@@ -115,7 +116,7 @@ public final class TemplateConfiguration extends Configurable implements ParserC
             return;
         }
         
-        if (((Configuration) cfg).getIncompatibleImprovements().intValue() < _TemplateAPI.VERSION_INT_2_3_22
+        if (((Configuration) cfg).getIncompatibleImprovements().intValue() < _VersionInts.V_2_3_22
                 && hasAnyConfigurableSet()) {
             throw new IllegalStateException(
                     "This TemplateConfiguration can't be associated to a Configuration that has "
@@ -190,6 +191,9 @@ public final class TemplateConfiguration extends Configurable implements ParserC
         if (tc.isDateTimeFormatSet()) {
             setDateTimeFormat(tc.getDateTimeFormat());
         }
+        if (tc.isCFormatSet()) {
+            setCFormat(tc.getCFormat());
+        }
         if (tc.isEncodingSet()) {
             setEncoding(tc.getEncoding());
         }
@@ -332,6 +336,9 @@ public final class TemplateConfiguration extends Configurable implements ParserC
         if (isDateTimeFormatSet() && !template.isDateTimeFormatSet()) {
             template.setDateTimeFormat(getDateTimeFormat());
         }
+        if (isCFormatSet() && !template.isCFormatSet()) {
+            template.setCFormat(getCFormat());
+        }
         if (isEncodingSet() && template.getEncoding() == null) {
             template.setEncoding(getEncoding());
         }
@@ -540,7 +547,7 @@ public final class TemplateConfiguration extends Configurable implements ParserC
     public boolean isOutputFormatSet() {
         return outputFormat != null;
     }
-    
+
     /**
      * See {@link Configuration#setRecognizeStandardFileExtensions(boolean)}. 
      */
@@ -679,6 +686,7 @@ public final class TemplateConfiguration extends Configurable implements ParserC
                 || isCustomNumberFormatsSet()
                 || isDateFormatSet()
                 || isDateTimeFormatSet()
+                || isCFormatSet()
                 || isLazyImportsSet()
                 || isLazyAutoImportsSet()
                 || isLocaleSet()
