@@ -54,6 +54,7 @@ import freemarker.cache.TemplateLookupResult;
 import freemarker.cache.TemplateLookupStrategy;
 import freemarker.cache.TemplateNameFormat;
 import freemarker.core.BaseNTemplateNumberFormatFactory;
+import freemarker.core.CFormat;
 import freemarker.core.CombinedMarkupOutputFormat;
 import freemarker.core.Configurable;
 import freemarker.core.Configurable.SettingValueAssignmentException;
@@ -67,6 +68,11 @@ import freemarker.core.EpochMillisDivTemplateDateFormatFactory;
 import freemarker.core.EpochMillisTemplateDateFormatFactory;
 import freemarker.core.HTMLOutputFormat;
 import freemarker.core.HexTemplateNumberFormatFactory;
+import freemarker.core.JSONCFormat;
+import freemarker.core.JavaCFormat;
+import freemarker.core.JavaScriptCFormat;
+import freemarker.core.JavaScriptOrJSONCFormat;
+import freemarker.core.LegacyCFormat;
 import freemarker.core.MarkupOutputFormat;
 import freemarker.core.OptInTemplateClassResolver;
 import freemarker.core.OutputFormat;
@@ -79,6 +85,7 @@ import freemarker.core.UndefinedOutputFormat;
 import freemarker.core.UnregisteredOutputFormatException;
 import freemarker.core.XHTMLOutputFormat;
 import freemarker.core.XMLOutputFormat;
+import freemarker.core.XSCFormat;
 import freemarker.core._CoreStringUtils;
 import freemarker.ext.beans.BeansWrapperBuilder;
 import freemarker.ext.beans.LegacyDefaultMemberAccessPolicy;
@@ -96,7 +103,7 @@ public class ConfigurationTest extends TestCase {
     public ConfigurationTest(String name) {
         super(name);
     }
-    
+
     public void testIncompatibleImprovementsChangesDefaults() {
         Version newVersion = Configuration.VERSION_2_3_21;
         Version oldVersion = Configuration.VERSION_2_3_20;
@@ -180,6 +187,20 @@ public class ConfigurationTest extends TestCase {
         cfg.setIncompatibleImprovements(Configuration.VERSION_2_3_27);
         assertTrue(((DefaultObjectWrapper) cfg.getObjectWrapper()).getTreatDefaultMethodsAsBeanMembers());
         assertFalse(((DefaultObjectWrapper) cfg.getObjectWrapper()).getPreferIndexedReadMethod());
+
+        cfg = new Configuration(Configuration.VERSION_2_3_0);
+        assertSame(LegacyCFormat.INSTANCE, cfg.getCFormat());
+        cfg.setIncompatibleImprovements(Configuration.VERSION_2_3_20);
+        assertSame(LegacyCFormat.INSTANCE, cfg.getCFormat());
+        cfg.setIncompatibleImprovements(Configuration.VERSION_2_3_21);
+        assertSame(LegacyCFormat.INSTANCE, cfg.getCFormat());
+        cfg.setIncompatibleImprovements(Configuration.VERSION_2_3_31);
+        assertSame(LegacyCFormat.INSTANCE, cfg.getCFormat());
+        cfg.setIncompatibleImprovements(Configuration.VERSION_2_3_32);
+        assertSame(JavaScriptOrJSONCFormat.INSTANCE, cfg.getCFormat());
+        cfg.setCFormat(JavaScriptOrJSONCFormat.INSTANCE); // Same as default, but explicitly set now
+        cfg.setIncompatibleImprovements(Configuration.VERSION_2_3_31);
+        assertSame(JavaScriptOrJSONCFormat.INSTANCE, cfg.getCFormat());
     }
 
     private void assertUses2322ObjectWrapper(Configuration cfg) {
@@ -286,6 +307,14 @@ public class ConfigurationTest extends TestCase {
             assertFalse(cfg.isCacheStorageExplicitlySet());
             assertTrue(cfg.getCacheStorage() instanceof SoftCacheStorage);
         }
+
+        assertFalse(cfg.isCFormatExplicitlySet());
+        //
+        cfg.setCFormat(XSCFormat.INSTANCE);
+        assertTrue(cfg.isCFormatExplicitlySet());
+        //
+        cfg.unsetCFormat();
+        assertFalse(cfg.isCFormatExplicitlySet());
     }
     
     public void testTemplateLoadingErrors() throws Exception {
@@ -334,7 +363,7 @@ public class ConfigurationTest extends TestCase {
     
     public void testVersion() {
         Version v = Configuration.getVersion();
-        assertTrue(v.intValue() > _TemplateAPI.VERSION_INT_2_3_20);
+        assertTrue(v.intValue() > _VersionInts.V_2_3_20);
         assertSame(v.toString(), Configuration.getVersionNumber());
         
         try {
@@ -1848,8 +1877,10 @@ public class ConfigurationTest extends TestCase {
             assertEquals(3, alg.getDefaultTerminatorLength());
             assertNull(alg.getDefaultMTerminator());
             assertNull(alg.getDefaultMTerminatorLength());
-            assertEquals(DefaultTruncateBuiltinAlgorithm.DEFAULT_WORD_BOUNDARY_MIN_LENGTH,
-                    alg.getWordBoundaryMinLength());
+            assertEquals(
+                    DefaultTruncateBuiltinAlgorithm.DEFAULT_WORD_BOUNDARY_MIN_LENGTH,
+                    alg.getWordBoundaryMinLength(),
+                    0);
         }
 
         {
@@ -1866,8 +1897,10 @@ public class ConfigurationTest extends TestCase {
             assertEquals("markupOutput(format=HTML, markup=<span class=trunc>...</span>)",
                     alg.getDefaultMTerminator().toString());
             assertEquals(Integer.valueOf(3), alg.getDefaultMTerminatorLength());
-            assertEquals(DefaultTruncateBuiltinAlgorithm.DEFAULT_WORD_BOUNDARY_MIN_LENGTH,
-                    alg.getWordBoundaryMinLength());
+            assertEquals(
+                    DefaultTruncateBuiltinAlgorithm.DEFAULT_WORD_BOUNDARY_MIN_LENGTH,
+                    alg.getWordBoundaryMinLength(),
+                    0);
         }
 
         {
@@ -1888,7 +1921,32 @@ public class ConfigurationTest extends TestCase {
         }
     }
 
-    @Test
+    public void testCFormat() throws TemplateException {
+        Configuration cfg = new Configuration(Configuration.VERSION_2_3_21);
+
+        assertSame(LegacyCFormat.INSTANCE, cfg.getCFormat());
+        cfg.setSetting(Configuration.C_FORMAT_KEY_SNAKE_CASE, LegacyCFormat.NAME);
+        assertSame(LegacyCFormat.INSTANCE, cfg.getCFormat());
+        cfg.setSetting(Configuration.C_FORMAT_KEY_CAMEL_CASE, JSONCFormat.NAME);
+        assertSame(JSONCFormat.INSTANCE, cfg.getCFormat());
+
+        cfg.setSetting(Configuration.C_FORMAT_KEY_CAMEL_CASE, "default");
+        cfg.setSetting(Configuration.C_FORMAT_KEY_SNAKE_CASE, LegacyCFormat.NAME);
+
+        for (CFormat standardCFormat : new CFormat[] {
+                        LegacyCFormat.INSTANCE,
+                        JSONCFormat.INSTANCE, JavaScriptCFormat.INSTANCE, JavaScriptOrJSONCFormat.INSTANCE,
+                        JavaCFormat.INSTANCE, XSCFormat.INSTANCE
+                }) {
+            cfg.setSetting(Configuration.C_FORMAT_KEY, standardCFormat.getName());
+            assertSame(standardCFormat, cfg.getCFormat());
+        }
+
+        // Object Builder value:
+        cfg.setSetting(Configuration.C_FORMAT_KEY, JSONCFormat.class.getName() + "()");
+        assertSame(JSONCFormat.INSTANCE, cfg.getCFormat());
+    }
+
     public void testFallbackOnNullLoopVariable() throws TemplateException {
         Configuration cfg = new Configuration(Configuration.VERSION_2_3_29);
         assertTrue(cfg.getFallbackOnNullLoopVariable());
