@@ -74,7 +74,7 @@ import freemarker.template.TemplateNodeModel;
 import freemarker.template.TemplateScalarModel;
 import freemarker.template.TemplateSequenceModel;
 import freemarker.template.Version;
-import freemarker.template._TemplateAPI;
+import freemarker.template._VersionInts;
 import freemarker.template.utility.NullArgumentException;
 import freemarker.template.utility.NullWriter;
 import freemarker.template.utility.StringUtil;
@@ -450,7 +450,7 @@ public class TemplateTestCase extends FileTestCase {
             dataModel.put("dow", dow);
             dataModel.put("dowPre22", dow
                     && ((DefaultObjectWrapper) conf.getObjectWrapper()).getIncompatibleImprovements()
-                            .intValue() < _TemplateAPI.VERSION_INT_2_3_22);
+                            .intValue() < _VersionInts.V_2_3_22);
         }
     }
     
